
import os
import re
import codecs
from setuptools import setup

setup(name='ndl_tense',
      version='0.0.1',
      description='',
      author='Adnane and Tek',
      packages=['data_preparation', 'data_analysis'])


from os import path, mkdir, sep

def check_folder_exist(filepath):
    if path.isdir(filepath):
        return
    else:
        mkdir(filepath)

def create_directories(dir_path, sep_file_path, folder_depth):
    for i in range(folder_depth):
        dir_path = sep.join([dir_path, sep_file_path[i + 1]])
        check_folder_exist(dir_path)

def manage_directories(dir_list, FILE_DIREC):
    for filepath in dir_list:
        sep_file_path = filepath.split(sep)
        dir_path = sep_file_path[0]
        if FILE_DIREC:  
            create_directories(dir_path, sep_file_path, (len(sep_file_path) - 2))
        else:
            create_directories(dir_path, sep_file_path, (len(sep_file_path) - 1))

def create_file(files_list, ext):
    for filepath in files_list:
        if path.isfile(filepath):
            return
        else:
            mkdir(filepath)



from setuptools import setup, Extension

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="ndl_tense",
    version="0.0.1",
    license = 'MIT',
    author="Tekevwe Kwakpovwe",
    author_email="t.kwakpovwe@gmail.com",
    description="A package for training NDL models",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    download_url= "https://github.com/ooominds/ndltenses/archive/refs/tags/test_1.tar.gz",
    keywords=["NDL", "Tense", "NLP"],
    install_requires=[
          'numpy',
          'h5py',
          'ntpath',
          'pandas',
          'pyndl',
          'sklearn',
          'keras',
          'xarray',
          'matplotlib',
    ],
    #project_urls={
    #    "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    #},
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=["ndl_tense"],
)
